@@ -1,5 +1,5 @@
 package App::Git::Info;
-$App::Git::Info::VERSION = '0.0.3';
+$App::Git::Info::VERSION = '0.2.0';
 # ABSTRACT: Displays a summary of information about the git repository.
 
 use strict;
@@ -7,10 +7,13 @@ use warnings;
 use 5.016;
 
 package main;
-$main::VERSION = '0.0.3';
+$main::VERSION = '0.2.0';
 use App::Rad;
 
-App::Rad->run;
+sub run
+{
+    return App::Rad->run;
+}
 
 sub info
 {
@@ -37,7 +40,7 @@ App::Git::Info - Displays a summary of information about the git repository.
 
 =head1 VERSION
 
-version 0.0.3
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -45,7 +48,7 @@ version 0.0.3
 
 =head1 VERSION
 
-version 0.0.3
+version 0.2.0
 
     shlomif@telaviv1:~/conf/trunk$ git info info
     ⇒ On branch master
